@@ -1,33 +1,31 @@
-import asyncio
 import time
-from typing import List, Union
 
 import grpc
 from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.generated_pb2 import Study as MDStudy
+from github.com.metaprov.modelaapi.services.study.v1.study_pb2_grpc import StudyServiceStub
 from github.com.metaprov.modelaapi.services.study.v1.study_pb2 import CreateStudyRequest, \
     UpdateStudyRequest, DeleteStudyRequest, GetStudyRequest, ListStudyRequest, \
     GetStudyProfileRequest, CreateStudyProfileRequest, AbortStudyRequest, PauseStudyRequest, ResumeStudyRequest
-from github.com.metaprov.modelaapi.services.study.v1.study_pb2_grpc import StudyServiceStub
 from tqdm import tqdm
 
-from modela.ModelaException import ModelaException, ResourceNotFoundException
 from modela.Resource import Resource
-from modela.common import *
+from modela.ModelaException import ModelaException, ResourceNotFoundException
+from typing import List, Union
+
 from modela.data.Dataset import Dataset
 from modela.infra.Lab import Lab
 from modela.infra.VirtualBucket import VirtualBucket
 from modela.training.Model import Model
-from modela.training.common import *
-from modela.training.models import ModelSearch, FeatureEngineeringSearch, BaselineSettings, Ensemble, Training, \
-    Interpretability, StudySchedule, NotificationSettings, StudySpec, StudyStatus, DataLocation
+from modela.training.common import TaskType, _StudyPhaseToProgress
+from modela.training.models import *
 
 
 class Study(Resource):
     def __init__(self, item: MDStudy = MDStudy(), client=None, namespace="", name="", version=Resource.DefaultVersion,
                  dataset: Union[str, Dataset] = "",
-                 test_dataset: Union[str, Dataset] = "",
                  lab: Union[ObjectReference, Lab, str] = "default-lab",
                  bucket: Union[VirtualBucket, str] = None,
+                 task_type: TaskType = None,
                  objective: Metric = None,
                  search: ModelSearch = None,
                  fe_search: FeatureEngineeringSearch = None,
@@ -36,10 +34,9 @@ class Study(Resource):
                  trainer_template: Training = None,
                  interpretability: Interpretability = None,
                  schedule: StudySchedule = None,
-                 notification: NotificationSettings = None,
+                 notification: NotificationSetting = None,
                  garbage_collect: bool = True,
                  keep_best_models: bool = True,
-                 fast: bool = False,
                  timeout: int = 600,
                  template: bool = False):
         """
@@ -50,11 +47,10 @@ class Study(Resource):
         :param version: The version of the resource.
         :param dataset: If specified as a string, the SDK will attempt to find a Dataset resource with the given name.
             If specified as a Dataset object, or if one was found with the given name, it will be used in the Study.
-        :param test_dataset: If specified, the Dataset will be used as the test dataset and the Dataset specified by
-            the `dataset` field will be used solely as the training dataset
-        :param lab: The object reference, Lab object, or lab name under the tenant of the resource for which all Study-related
+        :param lab: The object reference, Lab object, or lab name under the default-tenant for which all Study-related
             workloads will be performed under.
         :param bucket: The Bucket object or name of the bucket which will store the Study artifacts
+        :param task_type: The ML task type of the Study
         :param objective: The objective metric relevant to the task type.
         :param search: The search parameters define how many models to sample
         :param fe_search: The feature engineering search parameters of the Study
@@ -63,96 +59,72 @@ class Study(Resource):
         :param ensemble: The ensemble settings for the Study, which if enabled will combine the top estimators of
             the study after the initial model search.
         :param trainer_template: The training template for each model created by the Study.
-        :param interpretability: The interpretability configuration for the Study, which specifies what type of
-            model explainability plots will be generated from Shap values if they are computed
+        :param interpretability: The interpretability settings for the Study, which when enabled can produce ICE, LIME,
+            and Shap value plots
         :param schedule: The schedule for the study to run chronically
         :param notification: The notification settings, which if enabled will forward events about this resource to a notifier.
         :param garbage_collect: If enabled, models which did not move past the testing stage will be garbage collected by
             the system.
         :param keep_best_models: If enabled, the best models from each algorithm will not be garbage collected.
-        :param fast: If enabled, the Study will skip profiling, explaining, and reporting.
         :param timeout: The timeout in seconds after which the Study will fail.
         :param template: If the Study is a template it will not start a search and can only be used as a template for
             other studies.
         """
-        self.default_resource = False
         super().__init__(item, client, namespace=namespace, name=name, version=version)
-        if not self.default_resource:  # Ignore the rest of the constructor; studies are immutable
-            return
-
-        spec = self.spec
         if type(dataset) == Dataset:
-            dataset_name = dataset.name
-        else:
-            dataset_name = dataset
-            dataset = client.modela.Dataset(namespace=namespace, name=dataset)
-            if dataset.default_resource:
-                raise ResourceNotFoundException("Dataset {0} does not exist".format(dataset_name))
-
-        spec.DatasetName = dataset_name
-        spec.Task = dataset.spec.Task
-
-        if test_dataset:
-            if type(test_dataset) == Dataset:
-                test_dataset_name = dataset.name
-            else:
-                test_dataset_name = dataset
-                test_dataset = client.modela.Dataset(namespace=namespace, name=dataset)
-                if test_dataset.default_resource:
-                    raise ResourceNotFoundException("Dataset {0} does not exist".format(dataset_name))
-
-            spec.TrainingTemplate.Split.TrainDataset = dataset_name
-            spec.TrainingTemplate.Split.TestDataset = test_dataset_name
-            spec.TrainingTemplate.Split.Method = DataSplitMethod.TestDataset
+            dataset = dataset.name
+        self._object.spec.datasetName = dataset
 
         if type(lab) == Lab:
             lab = lab.reference
         elif type(lab) == str:
-            lab = ObjectReference(Namespace=client.modela.tenant, Name=lab)
+            lab = ObjectReference(Namespace="default-tenant", Name=lab)
+        self.spec.LabRef = lab
 
         if bucket is not None:
             if type(bucket) == VirtualBucket:
                 bucket = bucket.name
-            spec.Location = DataLocation(BucketName=bucket)
+            self.spec.Location = DataLocation(BucketName=bucket)
+
+        if task_type is not None:
+            self._object.spec.task = task_type.value
 
         if objective is not None:
-            spec.Search.Objective = objective
+            self._object.spec.search.objective = objective.value
+            self.spec.Search.Objective = objective
 
         if search is not None:
-            spec.Search = search
+            self.spec.Search = search
 
         if fe_search is not None:
-            spec.FeSearch = fe_search
+            self.spec.FeSearch = fe_search
 
         if baseline is not None:
-            spec.Baseline = baseline
+            self.spec.Baseline = baseline
 
         if ensemble is not None:
-            spec.Ensembles = ensemble
+            self.spec.Ensembles = ensemble
 
         if trainer_template is not None:
-            spec.TrainingTemplate = trainer_template
-
-        spec.TrainingTemplate.LabRef = lab
+            self.spec.TrainingTemplate = trainer_template
 
         if interpretability is not None:
-            spec.Interpretability = interpretability
+            self.spec.Interpretability = interpretability
 
         if schedule is not None:
-            spec.Schedule = schedule
+            self.spec.Schedule = schedule
 
         if notification is not None:
-            spec.Notification = notification
+            self.spec.Notification = notification
 
         if garbage_collect:
-            spec.Gc.CollectAtStudyEnd = True
+            self.spec.Gc.CollectAtStudyEnd = True
 
         if keep_best_models:
-            spec.Gc.KeepOnlyBestModelPerAlgorithm = True
+            self.spec.Gc.KeepOnlyBestModelPerAlgorithm = True
 
-        spec.Fast = fast
-        # spec.ActiveDeadlineSeconds = timeout
-        spec.Template = template
+        self._object.spec.activeDeadlineSeconds = timeout
+        self._object.spec.template = template
 
     @property
     def spec(self) -> StudySpec:
@@ -160,11 +132,9 @@ class Study(Resource):
 
     @property
     def status(self) -> StudyStatus:
-        self.sync()
         return StudyStatus().copy_from(self._object.status)
 
     def default(self):
-        self.default_resource = True
         StudySpec().apply_config(self._object.spec)
 
     def abort(self):
@@ -179,78 +149,31 @@ class Study(Resource):
         self.ensure_client_repository()
         self._client.resume(self.namespace, self.name)
 
-    def submit_and_visualize(self, replace: bool = False, show_progress_bar=True):
+    def submit_and_visualize(self, replace: bool = False):
         """
         Submit the resource and call visualize().
 
         :param replace: Replace the resource if it already exists on the cluster.
-        :param show_progress_bar: If enabled, the visualization will render a progress bar indicating the study progress.
         """
         self.submit(replace)
-        self.visualize(show_progress_bar)
+        self.visualize()
 
-    def visualize(self, show_progress_bar=True):
-        """
-        Display a real-time visualization of the Study's progress
-
-        :param show_progress_bar: If enabled, the visualization will render a progress bar indicating the study progress.
-        """
+    def visualize(self):
         desc = tqdm(total=0, position=0, bar_format='{desc}Time Elapsed: {elapsed}')
         bars = {}
 
         current_status, objective, cv_top, alg_top = None, self.spec.Search.Objective, 0, ""
         try:
             while True:
-                status = self.status
-                if current_status != status:
-                    current_status = status
+                self.sync()
+                if current_status != self.status:
+                    current_status = self.status
                     desc.set_description('Phase: %s | Active Models: %d | Best Algorithm: %s | Best Score: %s' %
-                                         (StudyPhaseToProgress[self.phase], current_status.Models,
+                                         (_StudyPhaseToProgress[self.phase], current_status.Models,
                                           alg_top if alg_top != "" else "[Waiting]",
                                           str(cv_top) if cv_top != 0 else "[Waiting]"))
 
-                    desc.refresh()
-
-                if current_status.Phase == StudyPhase.Failed:
-                    desc.set_description("Phase: Failed | Error Message: {0}".format(current_status.FailureMessage))
-                    desc.colour = "red"
-                    desc.refresh()
-                    time.sleep(5)
-                    self.sync()
-                    if self.phase != StudyPhase.Failed:
-                        continue
-                    else:
-                        break
-                elif current_status.Phase == StudyPhase.Completed:
-                    model = self._client.modela.Model(self.namespace, current_status.BestModel)
-                    if model.phase not in (ModelPhase.Completed, ModelPhase.Live):
-                        continue
-
-                    desc.close()
-                    for bar in bars.values():
-                        bar.close()
-
-                    if not show_progress_bar:
-                        desc.set_description_str("Study completed!")
-                        desc.refresh()
-
-                    print("\n\n" + model.details)
-                    if self.spec.Search.Trainers <= 2:
-                        print("Want quicker training speeds? Get more parallel trainers at https://modela.ai")
-
-                    time.sleep(0.1)
-                    return
-
-                time.sleep(0.1)
-                if not show_progress_bar:
-                    time.sleep(0.9)
-                    for model in self.models:
-                        if len(model.status.Cv) > 0:
-                            if model.get_cv_metric(objective) > cv_top:
-                                cv_top, alg_top = model.get_cv_metric(objective), model.spec.Estimator.AlgorithmName
-
-                    continue
-
+                desc.refresh()
                 models = self.models
                 for model in dict(bars).keys():
                     bar = bars[model]
@@ -315,24 +238,44 @@ class Study(Resource):
                             bars[model.name].postfix = unappendable_str(postfix)
                             bars[model.name].refresh()
 
+                if current_status.Phase == StudyPhase.Failed:
+                    desc.set_description("Phase: Failed | Error Message: {0}".format(current_status.FailureMessage))
+                    desc.colour = "red"
+                    desc.refresh()
+                    time.sleep(5)
+                    self.sync()
+                    if self.phase != StudyPhase.Failed:
+                        continue
+                    else:
+                        break
+                elif current_status.Phase == StudyPhase.Completed:
+                    model = self._client.modela.Model(self.namespace, current_status.BestModel)
+                    if model.phase != ModelPhase.Completed:
+                        continue
+
+                    desc.close()
+                    for bar in bars.values():
+                        bar.close()
+
+                    print("\n\n" + model.details)
+                    if self.spec.Search.Trainers <= 2:
+                        print("Want quicker training speeds? Get more parallel trainers at https://modela.ai")
+
+                    time.sleep(0.1)
+                    break
+
+                time.sleep(0.1)
+
         except KeyboardInterrupt:
             pass
 
-    async def wait_until_phase(self, phase: StudyPhase):
-        """ Returns a coroutine which blocks until the specified phase is reached, or the Study fails """
-        while self.status.Phase not in (phase, StudyPhase.Failed):
-            await asyncio.sleep(1/5)
-
-
     @property
     def models(self) -> List[Model]:
-        """ Get the list of currently active models produced by the Study """
         self.ensure_client_repository()
         return self._client.modela.Models.list(self.namespace, {'study': self.name})
 
     @property
     def best_model(self) -> Model:
-        """ Get the best model selected by the model search process """
         self.ensure_client_repository()
         return self._client.modela.Models.get(self.namespace, self._object.status.bestModel)
 
